==> codingtalk-uni-toolkit-0.0.7.tgz: package/src/core/formToolkit.js <==
import CUT from '../cut'

const formToolkit = {
    validate: (obj, config = { rqeuire: [] }) => {
        const result = {
            ok: true,
            form: null,
        };
        const _loop = (obj) => {
            if (Array.isArray(obj)) {
                return obj.map((i) => _loop(i));
            }
            const f = {};
            for (const i in obj) {
                if (i === "FILED") {
                    continue;
                }
                if (obj[i].skip) {
                    continue;
                }
                if (obj[i].toStr) {
                    f[i] = JSON.stringify(obj[i].value);
                    continue;
                }
                if (obj[i].skipFill && !obj[i].value) {
                    continue;
                }
                if (obj[i].require && !obj[i].value) {
                    if (
                        config.rqeuire &&
                        config.rqeuire.length &&
                        !config.rqeuire.includes(i)
                    ) {
                        continue;
                    }
                    $log4js.log(`validate error: key-------> ${i}`);
                    obj[i]._validator = {
                        ok: false,
                        msg: obj[i].errorTip || '请校验输入信息',
                    };
                    result.ok = false;
                }
                if (Array.isArray(obj[i].value)) {
                    if (!obj[i].value.length) {
                        f[i] = [];
                        continue;
                    }
                    obj[i].value.forEach((j) => {
                        let isSkipRow = false;
                        if (!f[i]) {
                            f[i] = [];
                        }
                        for (const k in j) {
                            if (
                                j[k].skipRowValue !== undefined &&
                                j[k].skipRowValue === j[k].value
                            ) {
                                isSkipRow = true;
                            }
                        }
                        if (isSkipRow) {
                            return;
                        }
                        f[i].push(_loop(j));
                    });
                    continue;
                }
                if (typeof obj[i].value === "object" && Object.keys(obj[i].value).length) {
                    f[i] = _loop(obj[i].value);
                    continue;
                }
                f[i] = obj[i].value;
            }
            return f;
        };
        result.form = _loop(obj);
        return result;
    },
    fill: (form, obj) => {
        const { _entityCollection } = CUT;
        for (const i in form) {
            if (i === "FILED") {
                continue;
            }
            if (form[i].skip) {
                form[i].value =
                    obj[i] ||
                    (() => {
                        const type = form[i].type.split("|")[0];
                        if (type === "array") {
                            return [];
                        }
                        if (type === "string") {
                            return "";
                        }
                        if (type === "boolean") {
                            return false;
                        }
                        return {};
                    })();
                continue;
            }
            if (form[i].skipFill) {
                continue;
            }
            if (form[i].toStr) {
                form[i].value = obj[i].toParse();
                continue;
            }
            const [typeValid, entity] = form[i].type.split(">");
            const [type] = typeValid.split("|");
            if (type === "array") {
                obj[i] &&
                    obj[i].forEach((j) => {
                        form[i].value.push(
                            formToolkit.fill(
                                _entityCollection[entity]
                                    .formUtil()
                                    .generator("update", "default"),
                                j
                            )
                        );
                    });
                continue;
            }
            if (type === "object") {
                form[i].value = formToolkit.fill(
                    _entityCollection[entity].formUtil().generator("update", "default"),
                    obj[i]
                );
                continue;
            }
            form[i].value = obj[i];
        }
        return form;
    },
};

export default formToolkit;

==> codingtalk-uni-toolkit-0.0.28.tgz: package/src/core/formToolkit.js <==
import global from '../global'

const formToolkit = {
    validate: (obj, config = { rqeuire: [] }) => {
        const result = {
            ok: true,
            form: null,
        };
        const _loop = (obj) => {
            if (Array.isArray(obj)) {
                return obj.map((i) => _loop(i));
            }
            const f = {};
            for (const i in obj) {
                if (i === "FILED") {
                    continue;
                }
                if (obj[i].skip) {
                    continue;
                }
                if (obj[i].toStr) {
                    f[i] = JSON.stringify(obj[i].value);
                    continue;
                }
                if (obj[i].skipFill && !obj[i].value) {
                    continue;
                }
                if (obj[i].require && !obj[i].value) {
                    if (
                        config.rqeuire &&
                        config.rqeuire.length &&
                        !config.rqeuire.includes(i)
                    ) {
                        continue;
                    }
                    $log4js.log(`validate error: key-------> ${i}`);
                    obj[i]._validator = {
                        ok: false,
                        msg: obj[i].errorTip || '请校验输入信息',
                    };
                    result.ok = false;
                }
                if (Array.isArray(obj[i].value)) {
                    if (!obj[i].value.length) {
                        f[i] = [];
                        continue;
                    }
                    obj[i].value.forEach((j) => {
                        let isSkipRow = false;
                        if (!f[i]) {
                            f[i] = [];
                        }
                        for (const k in j) {
                            if (
                                j[k].skipRowValue !== undefined &&
                                j[k].skipRowValue === j[k].value
                            ) {
                                isSkipRow = true;
                            }
                        }
                        if (isSkipRow) {
                            return;
                        }
                        f[i].push(_loop(j));
                    });
                    continue;
                }
                if (typeof obj[i].value === "object" && Object.keys(obj[i].value).length) {
                    f[i] = _loop(obj[i].value);
                    continue;
                }
                f[i] = obj[i].value;
            }
            return f;
        };
        result.form = _loop(obj);
        return result;
    },
    fill: (form, obj) => {
        const { _entityCollection } = global;
        for (const i in form) {
            if (i === "FILED") {
                continue;
            }
            if (form[i].skip) {
                form[i].value =
                    obj[i] ||
                    (() => {
                        const type = form[i].type.split("|")[0];
                        if (type === "array") {
                            return [];
                        }
                        if (type === "string") {
                            return "";
                        }
                        if (type === "boolean") {
                            return false;
                        }
                        return {};
                    })();
                continue;
            }
            if (form[i].skipFill) {
                continue;
            }
            if (form[i].toStr) {
                form[i].value = obj[i].toParse();
                continue;
            }
            const [typeValid, entity] = form[i].type.split(">");
            const [type] = typeValid.split("|");
            if (type === "array") {
                obj[i] &&
                    obj[i].forEach((j) => {
                        form[i].value.push(
                            formToolkit.fill(
                                _entityCollection[entity]
                                    .formUtil()
                                    .generator("update", "default"),
                                j
                            )
                        );
                    });
                continue;
            }
            if (type === "object") {
                form[i].value = formToolkit.fill(
                    _entityCollection[entity].formUtil().generator("update", "default"),
                    obj[i]
                );
                continue;
            }
            form[i].value = obj[i];
        }
        return form;
    },
};

export default formToolkit;
